<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_a1e707d02a236dadebd15" . "a45e65ebdb6" => base64_decode("YXR0YWNobWVudC1jb3Vud" . "A=="), "_8c575917cbaedf" . "1e7efae84939402" . "bff" => base64_decode("U3Via" . "mVjdA" . "=="), "_f589476007fa133f457c3ef29dd" . "fa566" => base64_decode("VG8" . "="), "_956cd32298a229f9768f1096f07" . "7ace3" => base64_decode("Ym9keS1wbGFpb" . "g=="), "_44e986c04f41" . "a08b56a383c7b" . "3a88ee2" => base64_decode("c2VuZ" . "GVy"), "_9c050c786fc87" . "170cbb84fc6a8b" . "13cb6" => base64_decode("YXR0YWNob" . "WVudC0="), "_6e1c717cf3cbf1af982ed7" . "4d4336b7f1" => base64_decode("Ym9k" . "eS1o" . "dG1s"), "_d706c160e4" . "5bf7434fff8" . "2a5976f0e19" => base64_decode("YXJyYXlfa2V5" . "cw=="), "_618a4aeb9fecc4592a4521f34" . "876fa29" => base64_decode("ZnJvbQ=" . "="), "_f39f5346e313e4" . "dd1ac3a7bd8032b" . "eda" => base64_decode("c3Vic3R" . "yX2NvbX" . "BhcmU="), "_97ea09a7faf27c52c6eff69773df" . "1d8a" => base64_decode("dGltZ" . "XN0YW" . "1w"), "_1d6c68a0262e8" . "fa0bed1215b722" . "4a98e" => base64_decode("cmVjaXB" . "pZW50"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_d706c160e45bf7434fff82a5976f0e1" . "9"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_a1e707d02a236dadeb" . "d15a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_f39f5346e313e4dd1ac3a7bd8032bed" . "a"]($key, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_9c050c786fc87170cbb84fc6a8" . "b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_1d6c68a0" . "262e8fa0b" . "ed1215b72" . "24a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_618a4aeb9fecc4592a4521f34876fa2" . "9"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_f589476007fa133f457c3ef2" . "9ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_8c575917cbaedf1e7ef" . "ae84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_6e1c717" . "cf3cbf1a" . "f982ed74" . "d4336b7f" . "1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_956cd32298a229f" . "9768f1096f077ace" . "3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_97ea09a7faf27c52c6eff69773df1" . "d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_44e986c04f4" . "1a08b56a383c" . "7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}