<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array("_618a4aeb9fecc" . "4592a4521f3487" . "6fa29" => base64_decode("ZnJv" . "bQ=="), "_376d30c4085735" . "7a4d4cbb1ffaa25" . "817" => base64_decode("dG8" . "="), "_c3547336" . "4fa7a0502" . "99058f332" . "ec29c1" => base64_decode("ZXhjZXB0aW" . "9u"), "project_" . "id" => base64_decode("cHJvam" . "VjdF9p" . "ZA=="), "_e608e5b5c4c34a67ba97ef84c1" . "e16199" => base64_decode("J" . "w" . "=" . "="), "_bfda889b74" . "ea561b14325" . "e30e7d75426" => base64_decode("Ym9k" . "eV9o" . "dG1s"), "_f656816961e8573806141c558b" . "184fe2" => base64_decode("c3Viam" . "VjdA=="), "_ced92d7b391285c8a26846f1f4bd3" . "128" => base64_decode("Ym9ke" . "V90ZX" . "h0"), "_03b1f0cee835582d1158dce26" . "78b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUg" . "bWFpbCByZWNlaXZlZCBzdWJzY3Jp" . "YmVy"), "_5d40a2cf1c52" . "5fb252bf5599e" . "339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3IgbWFpbDsgc3ViamVj" . "dCAn"), "_460e1aeb3" . "113a1676ce" . "59a8f40431" . "d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHByb2plY3" . "Q="), "_67a0d624aebcceb0abd5ce56" . "a53ff06f" => base64_decode("ZG" . "F0" . "ZQ" . "=="), "_9b16fa2683095" . "e67d7c8b265a80" . "81d0b" => base64_decode("TWFpbFJlY2VpdmV" . "kRXZlbnRSZWNlaX" . "Zlcg=="), "_a3d82c5df38e194c9c" . "73e3ccb4223bbc" => base64_decode("ZW1haWxfZGF0YQ" . "=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_9b16fa2683095e" . "67d7c8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_03b1f0cee835582d1158dce2678" . "b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_5d40a2cf1c525fb2" . "52bf5599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_e608e5b5c4c34a67ba97ef8" . "4c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_618a4aeb9fecc4592a4521f34876fa" . "29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_376d30c40857357a4d4cbb1ffaa" . "25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_f656816961e8573806141c558b184fe" . "2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_ced92d7b391285c8a26846f1f4bd31" . "28"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_bfda889b74ea561b" . "14325e30e7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_67a0d624aebcceb0abd5ce56a53ff0" . "6f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_460e1aeb3113" . "a1676ce59a8f4" . "0431d5c"], [$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["projec" . "t_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_a3d82c5df38e194c9c73e3ccb4223b" . "bc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_c35473364fa7a" . "050299058f332e" . "c29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}